Struct SentryLayer
pub struct SentryLayer<S> { /* private fields */ }Expand description
Provides a tracing layer that dispatches events to sentry
Implementations
impl<S> SentryLayer<S>
impl<S> SentryLayer<S>
pub fn event_filter<F>(self, filter: F) -> SentryLayer<S>
pub fn event_filter<F>(self, filter: F) -> SentryLayer<S>
Sets a custom event filter function.
The filter classifies how sentry should handle [Event]s based
on their [Metadata].
pub fn event_mapper<F>(self, mapper: F) -> SentryLayer<S>
pub fn event_mapper<F>(self, mapper: F) -> SentryLayer<S>
Sets a custom event mapper function.
The mapper is responsible for creating either breadcrumbs or events from
[Event]s.
pub fn span_filter<F>(self, filter: F) -> SentryLayer<S>
pub fn span_filter<F>(self, filter: F) -> SentryLayer<S>
Sets a custom span filter function.
The filter classifies whether sentry should handle tracing::Spans based
on their [Metadata].
pub fn enable_span_attributes(self) -> SentryLayer<S>
pub fn enable_span_attributes(self) -> SentryLayer<S>
Enable every parent span’s attributes to be sent along with own event’s attributes.
Note that the root span is considered a transaction
so its context will only be grabbed only if you set the transaction to be sampled.
The most straightforward way to do this is to set
the traces_sample_rate to 1.0
while configuring your sentry client.